@@ -16,13 +16,14 @@ use OCA\Passwords\Events\PasswordRevision\BeforePasswordRevisionCreatedEvent;
 use OCA\Passwords\Events\PasswordRevision\BeforePasswordRevisionUpdatedEvent;
 use OCA\Passwords\Helper\Settings\UserSettingsHelper;
 use OCP\EventDispatcher\Event;
+use OCP\EventDispatcher\IEventListener;
 
 /**
  * Class BeforePasswordRevisionSavedEventListener
  *
  * @package OCA\Passwords\EventListener\PasswordRevision
  */
-class BeforePasswordRevisionSavedEventListener {
+class BeforePasswordRevisionSavedEventListener implements IEventListener {
 
     /**
      * @var UserSettingsHelper
