@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\Password;
@@ -17,26 +21,14 @@ use OCP\EventDispatcher\Event;
  */
 class PasswordClonedEvent extends Event {
 
-    /**
-     * @var Password
-     */
-    protected Password $original;
-
-    /**
-     * @var Password
-     */
-    protected Password $clone;
-
     /**
      * PasswordClonedEvent constructor.
      *
      * @param Password $original
      * @param Password $clone
      */
-    public function __construct(Password $original, Password $clone) {
+    public function __construct(protected Password $original, protected Password $clone) {
         parent::__construct();
-        $this->original = $original;
-        $this->clone = $clone;
     }
 
     /**
