@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\TagRevision;
@@ -17,26 +21,14 @@ use OCP\EventDispatcher\Event;
  */
 class AfterTagRevisionClonedEvent extends Event {
 
-    /**
-     * @var TagRevision
-     */
-    protected TagRevision $original;
-
-    /**
-     * @var TagRevision
-     */
-    protected TagRevision $clone;
-
     /**
      * BeforeTagRevisionClonedEvent constructor.
      *
      * @param TagRevision $original
      * @param TagRevision $clone
      */
-    public function __construct(TagRevision $original, TagRevision $clone) {
+    public function __construct(protected TagRevision $original, protected TagRevision $clone) {
         parent::__construct();
-        $this->original = $original;
-        $this->clone = $clone;
     }
 
     /**
