@@ -17,16 +17,16 @@ use Throwable;
  */
 class InvalidFaviconDataException extends Exception {
 
-    const EXCEPTION_CODE    = 101;
+    const EXCEPTION_CODE       = 101;
     const EXCEPTION_MESSAGE = 'Favicon service returned unsupported data type: ';
 
     /**
      * InvalidFaviconDataException constructor.
      *
-     * @param string          $mime
+     * @param string         $mime
      * @param Throwable|null $previous
      */
-    public function __construct(string $mime, Throwable $previous = null) {
+    public function __construct(string $mime, ?Throwable $previous = null) {
         parent::__construct(static::EXCEPTION_MESSAGE.$mime, static::EXCEPTION_CODE, $previous);
     }
 }
\ No newline at end of file
